##### Analysis of competition data #####
# J. P. J. Hall, August 2018

# Analysis ----------------------------------------------------------------

rm(list=ls())
source("~/.Rprofile")
# Loads summarySE function available here 
#   http://www.cookbook-r.com/Manipulating_data/Summarizing_data/
library(ggplot2)
library(grid)
library(car)

data <- read.table("./data/SuppTab3.csv",
                   header=TRUE, sep=",")
head(data)


# 1. Check controls (ancestors) -------------------------------------------

data.controls <- subset(data, cul == "anc")
control.plotr <- ggplot(data=data.controls, aes(x=test_mer, 
                                              y=fitness, 
                                              colour=cln_rep,
                                              group=interaction(cln_rep,evo_rep))) +
  geom_hline(yintercept=0) +
  geom_line() +
  geom_point(size=2) +
  coord_trans(limy=c(-0.1,0.4), limx=c(-5,21)) +
  scale_x_continuous(breaks=c(0,16)) +
  labs(y="fitness of Gm-labelled (s)",
       x="test mercury (µg/g)") +
  theme_pub() + theme(legend.position="right")
control.plotr

# Is there a marker effect with the ancestral controls?
control.groups <- as.factor(data.controls$test_mer)
control.mod1 <- lm(data=data.controls, fitness ~ test_mer)
par(mfrow=c(1,1))
boxplot(data.controls$fitness ~ control.groups)
bartlett.test(x = data.controls$fitness, g = control.groups)
# Bartlett's K-squared = 0.11407, df = 1, p-value = 0.7356
fligner.test(x = data.controls$fitness, g = control.groups)
# Fligner-Killeen:med chi-squared = 0.48512, df = 1, p-value = 0.4861
shapiro.test(resid(control.mod1))
# W = 0.96038, p-value = 0.3168
par(mfrow=c(2,2))
plot(control.mod1)

summary(control.mod1)
anova(control.mod1) 
# Response: fitness
#           Df   Sum Sq   Mean Sq F value Pr(>F)
# test_mer   1 0.007501 0.0075012  1.4201 0.2434
# Residuals 28 0.147904 0.0052823     

# no effect of test mercury on ancestral control fitness
# (i.e. no marker * mercury interaction)

t.test(x=data.controls$fitness, mu=0) 
# However, ancestral Gm significantly fitter than Sm (t = 9.9815, df = 29, p-value = 6.883e-11)

# Standardize fitness of evolved clones across markers
# by subtracting ancestral fitness
# Convert to 'evolved fitness' by taking 0-fitness for evolved Sm-labelled lines
# (since fitness was measured as Gm-labelled fitness)
controls_mean  <- mean(data.controls$fitness)

data$fitness_evolved <- data$fitness - controls_mean
data[data$mrk=="Sm","fitness_evolved"] <- (0-data[data$mrk=="Sm","fitness_evolved"])

# Analysis ----------------------------------------------------------------

# quick plot
ggplot(data=data, aes(x=test_mer, y=fitness_evolved, 
                      colour=cul, group=interaction(cul,cln_rep,evo_rep,evo_mer))) +
  geom_point() + geom_line() + facet_wrap(~evo_mer) + scale_colour_brewer(type="qual")

d1<-data[,c("evo_rep","cln_rep","test_mer","evo_mer","cul","fitness_evolved")]

d1<-subset(d1, cul != "anc") 
# we're interested whether the evolved treatments differ, so remove measurements of ancestor
d1<-droplevels(d1)

# Mercury should be a factor (present/absent)
d1$evo_mer <- factor(d1$evo_mer)
d1$test_mer <- factor(d1$test_mer)

d1$pop<-as.factor(paste(d1$evo_rep, d1$cul, d1$evo_mer, sep="."))

# Data exploration.
# First test and run a simple linear model including everything

# Data diagnostics: homogeneity of variance
d1.groups<-as.factor(paste(d1$cul, d1$evo_mer, d1$test_mer))
par(mfrow=c(1,1))
boxplot(d1$fitness_evolved ~ d1.groups) # maybe ok?
bartlett.test(x = d1$fitness_evolved, g = d1.groups) 
# Bartlett's K-squared = 14.437, df = 7, p-value = 0.04393
# no, Bartlett's is slightly off
fligner.test(x = d1$fitness_evolved, g = d1.groups) 
# Fligner-Killeen:med chi-squared = 5.9457, df = 7, p-value = 0.5461
# fligner is ok
leveneTest(d1$fitness_evolved ~ d1.groups) # levene's is ok
# Levene's Test for Homogeneity of Variance (center = median)
#        Df F value Pr(>F)
# group   7   0.763 0.6188
#       312 
# Normality of residuals
shapiro.test(resid(lm(data=d1, fitness_evolved ~ d1.groups))) 
# W = 0.90243, p-value = 1.675e-13
# shapiro test is way out

# Box-cox transform
library(MASS)
# necessary to add 1 to fitness_evolved, since some values are <0
boxcox(((fitness_evolved+1)) ~ cul * evo_mer * test_mer, data=d1, 
       lambda=seq(0,4,0.5))
boxcox(((fitness_evolved+1)) ~ cul * evo_mer * test_mer, data=d1, 
       lambda=seq(1,3.5,0.2))
# estimate lambda at 2.5
lbd <- 2.5
d1$f.boxcox<-(((d1$fitness_evolved+1)^lbd)-1)/lbd
boxplot(d1$f.boxcox ~ d1.groups)
# variance still seems off
bartlett.test(x = d1$f.boxcox, g = d1.groups) 
# Bartlett's K-squared = 17.71, df = 7, p-value = 0.01335
fligner.test(x = d1$f.boxcox,  g = d1.groups) 
# Fligner-Killeen:med chi-squared = 11.779, df = 7, p-value = 0.1081
leveneTest(d1$f.boxcox ~ d1.groups) #  0.08106
# shapiro.test(resid(lm(data=d1, f.boxcox ~ d1.groups))) W = 0.98516, p-value = 0.002221
qqPlot(resid(lm(data=d1, f.boxcox ~ d1.groups)))
# Tests for homogeneity of variance are worse, 
#   normality is better, but still significantly off.
# 
# The analysis will therefore be fairly complex.
# First, run a couple of simple analyses

# Simple model ------------------------------------------------------------

mod.lm<-lm(f.boxcox ~ cul * evo_mer * test_mer, data=d1)
par(mfrow=c(2,2))
plot(mod.lm)
E <- rstandard(mod.lm)
par(mfrow=c(1,1))
boxplot(E ~ pop + test_mer, data = d1, axes = FALSE, ylim = c(-8,5))
abline(0,0); axis(2)
text(1:46, -6, cex=0.75, srt=60) 
shapiro.test(residuals(mod.lm))

# Though this basic model violates the assumptions of normal distribution of residuals
#   and homogenous variance across factor levels,
#   it can still give us a clue of patterns in the data

step(mod.lm) # f.boxcox ~ cul + evo_mer + test_mer + cul:evo_mer
mod.lm.reduced <- lm(f.boxcox ~ cul + evo_mer + test_mer + cul:evo_mer, data=d1)
drop1(mod.lm.reduced, test="F")
# f.boxcox ~ cul + evo_mer + test_mer + cul:evo_mer
#             Df Sum of Sq    RSS     AIC F value   Pr(>F)    
# <none>                   33.132 -715.70                     
# test_mer     1    3.4954 36.628 -685.61 33.2318 1.95e-08 ***
# cul:evo_mer  1    0.2401 33.372 -715.39  2.2823   0.1319   
mod.lm.reduced2 <- lm(f.boxcox ~ cul + evo_mer + test_mer, data=d1)
drop1(mod.lm.reduced2, test="F")
# f.boxcox ~ cul + evo_mer + test_mer
#          Df Sum of Sq    RSS     AIC F value    Pr(>F)    
# <none>                33.372 -715.39                      
# cul       1    2.9951 36.367 -689.89 28.3607 1.915e-07 ***
# evo_mer   1    0.2050 33.577 -715.43  1.9414    0.1645    
# test_mer  1    3.4954 36.868 -685.51 33.0975 2.071e-08 ***
mod.lm.reduced3 <- lm(f.boxcox ~ cul + test_mer, data=d1)
drop1(mod.lm.reduced3, test="F")
# f.boxcox ~ cul + test_mer
#          Df Sum of Sq    RSS     AIC F value    Pr(>F)    
# <none>                33.577 -715.43                      
# cul       1    2.9227 36.500 -690.72  27.593 2.752e-07 ***
# test_mer  1    3.4954 37.073 -685.74  32.999 2.162e-08 ***

# Model output consistent with plot:
#   Significant effects of test mercury and co-culture

t(t(coef(mod.lm.reduced3)))
# (Intercept) 0.3236009
# culss       0.1912742
# test_mer16  0.2090269
# Suggests that clones from single-species populations have increased fitness gains.
# Evolved clones have increased fitness when tested in mercury.

# However, note that this simple model does not account for pseudoreplication:
#  7 plasmid-bearing clones were tested from 6 populations (5 for co-cultured at 0 µg/g).
# How does the model look if we average fitness across clones from each population?

head(d1)
d1_pop <- summarySE(data=d1, measurevar="f.boxcox", 
                    groupvars=c("evo_rep","test_mer","evo_mer","cul"))
ggplot(data=d1_pop, aes(y=f.boxcox, x=test_mer, colour=cul)) +
  geom_point() + facet_grid(.~evo_mer) + geom_line(aes(group=interaction(evo_rep,cul)))
head(d1_pop)
nrow(d1_pop) # 46: 2 tests * 2 mercury * 2 co-cultured * 6 populations, missing 2 co-cultured 0 µg/g
mod.lm_pop<-lm(f.boxcox ~ cul * evo_mer * test_mer, data=d1_pop)
par(mfrow=c(2,2))
plot(mod.lm_pop)
d1_pop.groups <- as.factor(paste(d1_pop$cul, d1_pop$evo_mer, d1_pop$test_mer))
bartlett.test(x = d1_pop$f.boxcox, g = d1_pop.groups) # p-value = 0.9601
fligner.test(x = d1_pop$f.boxcox,  g = d1_pop.groups) # p-value = 0.9688
leveneTest(d1_pop$f.boxcox ~ d1_pop.groups) # 0.9494
shapiro.test(resid(mod.lm_pop)) # p-value = 0.03417

step(mod.lm_pop) # cul + test_mer, interactions not significant
mod.lm_pop.reduced <- lm(f.boxcox ~ cul + test_mer, data=d1_pop)
drop1(mod.lm_pop.reduced, test="F") 
# Df Sum of Sq    RSS     AIC F value   Pr(>F)   
# <none>                1.8393 -142.09                    
# cul       1   0.43066 2.2700 -134.41  10.068 0.002785 **
# test_mer  1   0.50248 2.3418 -132.97  11.747 0.001354 **

t(t(coef(mod.lm_pop.reduced)))
# (Intercept) 0.3235991
# culss       0.1937009
# test_mer16  0.2090305

# This model, averaging clones within each population, matches eyeballing,
# and matches the non-averaged (pseudoreplicated) model:
#   Significant positive effects of test mercury and single-species culture
# However note it still does not meet model assumptions (Shapiro-Wilk)



# Complex model -----------------------------------------------------------

# A better model would be one where the model takes into account correlation in the data
#   (repeated measures), and accommodates heterogenous variances.
# Assess random effects: this must be decided first (Zuur 2009 p 132)

# Several clones were measured from each population
#     Random effect of population (~1|pop)

library(nlme)

# Exploratory studies shows that following steps require alternative optimizer
ctrl <- lmeControl(opt='optim')

mod.gls<-gls(f.boxcox ~ cul * evo_mer * test_mer, 
             data=d1, method="REML", control=ctrl)
mod.lmm<-lme(f.boxcox ~ cul * evo_mer * test_mer,  
             random=~1|pop, data=d1, method="REML", control=ctrl)
anova(mod.gls, mod.lmm)
#         Model df      AIC      BIC     logLik   Test L.Ratio p-value
# mod.gls     1  9 231.9863 265.6733 -106.99315                       
# mod.lmm     2 10 155.4437 192.8737  -67.72185 1 vs 2 78.5426  <.0001
loglik <- 2*(c(logLik(mod.lmm)-logLik(mod.gls)))
0.5 * (1 - pchisq(loglik, 1))
# p = 0, so random effects make a significant contribution


# Test with different variance structures
# Keep population as a random effect

fcul <- as.factor(d1$cul)
fevo_mer <- as.factor(d1$evo_mer)
ftest_mer <- as.factor(d1$test_mer)
fpop <- as.factor(d1$pop)

mod.gls. <- gls(f.boxcox~ fcul * fevo_mer * ftest_mer, data=d1, method="REML")

vf1Ident <- varIdent(form = ~ 1|fcul)
vf2Ident <- varIdent(form = ~ 1|fevo_mer)
vf3Ident <- varIdent(form = ~ 1|ftest_mer)
vf4Ident <- varIdent(form = ~ 1|fcul*fevo_mer)
vf5Ident <- varIdent(form = ~ 1|fcul*ftest_mer)
vf6Ident <- varIdent(form = ~ 1|fevo_mer*ftest_mer)
vf7Ident <- varIdent(form = ~ 1|fcul*fevo_mer*ftest_mer)
vf8Ident <- varIdent(form = ~ 1|fpop)
vf9Ident <- varIdent(form = ~ 1|fpop*ftest_mer)

# Fit LMM models incorporating heterogenous variances. 
# Note that optimal residual variance needs be assessed using REML (Zuur2009)
# (lme() defaults to REML)

m.lmm <- lme(f.boxcox~ fcul * fevo_mer * ftest_mer, 
             random = ~1|pop, data=d1, control=ctrl)
m.lmm1 <- lme(f.boxcox~ fcul * fevo_mer * ftest_mer,
              random = ~1|pop, data=d1, weights = vf1Ident, control=ctrl)
m.lmm2 <- lme(f.boxcox~ fcul * fevo_mer * ftest_mer, 
              random = ~1|pop, data=d1, weights = vf2Ident, control=ctrl)
m.lmm3 <- lme(f.boxcox~ fcul * fevo_mer * ftest_mer, 
              random = ~1|pop, data=d1, weights = vf3Ident, control=ctrl)
m.lmm4 <- lme(f.boxcox~ fcul * fevo_mer * ftest_mer, 
              random = ~1|pop, data=d1, weights = vf4Ident, control=ctrl)
m.lmm5 <- lme(f.boxcox~ fcul * fevo_mer * ftest_mer, 
              random = ~1|pop, data=d1, weights = vf5Ident, control=ctrl)
m.lmm6 <- lme(f.boxcox~ fcul * fevo_mer * ftest_mer, 
              random = ~1|pop, data=d1, weights = vf6Ident, control=ctrl)
m.lmm7 <- lme(f.boxcox~ fcul * fevo_mer * ftest_mer, 
              random = ~1|pop, data=d1, weights = vf7Ident, control=ctrl)
m.lmm8 <- lme(f.boxcox~ fcul * fevo_mer * ftest_mer, 
              random = ~1|pop, data=d1, weights = vf8Ident, control=ctrl)
m.lmm9 <- lme(f.boxcox~ fcul * fevo_mer * ftest_mer, 
              random = ~1|pop, data=d1, weights = vf9Ident, control=ctrl)     

aic <- data.frame(AIC(m.lmm1, m.lmm2, m.lmm3, 
                      m.lmm4, m.lmm5, m.lmm6,
                      m.lmm7, m.lmm8, m.lmm9))
aic[with(aic, order(AIC)),]

# Best structure is with variance varying with population (m.lmm8)
library(lmtest)
lrtest(m.lmm, m.lmm8) # complex model significantly better (p = 1.077e-09)
E2 <- resid(m.lmm8, type = "normalized")
F2 <- fitted(m.lmm8)
fitted_residuals <- data.frame(cbind(E2,F2))

ggplot(data=fitted_residuals, aes(x=F2, y=E2)) + 
  geom_point() + labs(x="fitted",y="resid") + theme_bw()
# residuals plot looks good
d1.groups<-as.factor(paste(d1$cul, d1$evo_mer, d1$test_mer))
bartlett.test(E2, d1.groups) # p-value = 0.07184
fligner.test(E2, d1.groups)  # p-value = 0.281
# Plot residuals against factors to look for patterns
d.lmm8<-cbind(d1, resid(m.lmm8, type="normalized"))
ggplot(data=d.lmm8, aes(x=evo_mer, y=E2)) + geom_boxplot() + 
  labs(x="evolved_mercury",y="resid") + theme_bw()
ggplot(data=d.lmm8, aes(x=as.factor(test_mer), y=E2)) + geom_boxplot() + 
  labs(x="test_mercury",y="resid") + theme_bw()
ggplot(data=d.lmm8, aes(x=fcul, y=E2)) + geom_boxplot() + 
  labs(x="alone_putida",y="resid") + theme_bw()
ggplot(data=d.lmm8, aes(x=pop, y=E2)) + geom_boxplot() + 
  labs(x="pop",y="resid") + theme_bw() + 
  theme(axis.text.x=element_text(angle=90, hjust=1, vjust=0.5))
# No obvious patterns

shapiro.test(E2) # W = 0.99491, p-value = 0.3716
qqPlot(E2) 
# qqPlot looks good, suggesting that this model meets assumptions

# Model reduction
m.lmm8. <- update(m.lmm8, .~., method="ML")
m.lmm8.a <- update(m.lmm8., .~.-fcul:fevo_mer:ftest_mer)
anova(m.lmm8., m.lmm8.a)
#          Model df      AIC     BIC    logLik   Test  L.Ratio p-value
# m.lmm8.      1 32 82.39270 202.979 -9.196352                        
# m.lmm8.a     2 31 81.42903 198.247 -9.714516 1 vs 2 1.036328  0.3087

m.lmm8.b <- stepAIC(m.lmm8.a)
summary(m.lmm8.b)
# Fixed effects: f.boxcox ~ fcul + ftest_mer
drop1(m.lmm8.b, test="Chisq")

# Single term deletions
# 
# Model:
#   f.boxcox ~ fcul + ftest_mer
# Df     AIC    LRT  Pr(>Chi)    
# <none>        76.842                     
# fcul       1  79.777  4.934   0.02633 *  
# ftest_mer  1 136.953 62.111 3.246e-15 ***

# final model is f.boxcox ~ fcul + ftest_mer

# refit as REML
mod.final1 <- update(m.lmm8.b, method="REML")

t(t(fixef(mod.final1)))
# (Intercept) 0.3385621
# fculss      0.1937025
# ftest_mer16 0.1862896

# Validate model
d1$resid2 <- resid(mod.final1, type = "normalized")
d1$fitted2 <- fitted(mod.final1)
grid.newpage()
pushViewport(viewport(layout=grid.layout(2,2))) 
print((ggplot(data=d1, aes(x=fitted2, y=resid2)) + geom_point()),
      vp=viewport(layout.pos.col=1,layout.pos.row=1))
print((ggplot(data=d1, aes(x=evo_mer, y=resid2)) + geom_boxplot()),
      vp=viewport(layout.pos.col=2,layout.pos.row=1))
print((ggplot(data=d1, aes(x=test_mer, y=resid2)) + geom_boxplot()),
      vp=viewport(layout.pos.col=1,layout.pos.row=2))
print((ggplot(data=d1, aes(x=cul, y=resid2)) + geom_boxplot()),
      vp=viewport(layout.pos.col=2,layout.pos.row=2))
ggplot(data=d1, aes(x=pop, y=resid2)) + geom_boxplot() +
  theme(axis.text.x=element_text(angle=90, hjust=1, vjust=0.5))
# All looks good

# and this is the table for quoting significance
#           Df     AIC    LRT  Pr(>Chi)    
# <none>        76.842                     
# fcul       1  79.777  4.934   0.02633 *  
# ftest_mer  1 136.953 62.111 3.246e-15 ***
