##### Analysis of mutations from soil sequencing experiment #####
# J. P. J. Hall, August 2018

rm(list=ls())

library(plyr)
library(reshape2)
library(vegan)
library(grid)

# Data is from https://doi.org/10.5061/dryad.6gf28
vardata <- read.csv("S1_VarData.csv",
                   sep=",", header=TRUE)

summary(vardata)

# Analysis:
# 1. Resolve nestedness in data structure (some populations have >1 clone sequenced)
# 2. Analyse mutational distance between populations (PERMANOVA)
# 3. Identify parallel mutations and treatment-specific parallel mutations

# First add more complete information on the deleted loci
# Identified by manual examination of deletions and sequences
vardata$target <- as.character(vardata$target)
vardata[with(vardata, 
             target=="PP_1563" & sample_number %in% c(57,58) &
               effect=="deletion"),
        "target"] <- "prophage4"
vardata[with(vardata, 
             target %in% c("PP_3058", "PP_3047") & 
               sample_number %in% c(55, 61) & effect=="deletion"),
        "target"] <- "prophage2"
vardata[with(vardata, 
             target=="PP_3878" & sample_number==22 & effect=="deletion"),
        "target"] <- "prophage1"
vardata[with(vardata, 
             target=="PP_0167-0168" & effect=="deletion"),
        "target"] <- "PP_0167"
vardata$target <- factor(vardata$target)

# 1. Within-population variation ---------------------------------------------

# How many mutations/sequenced clone?
m_count_pf <- data.frame(table(vardata[vardata$spc=="Pf","sample_number"]))
m_count_pp <- data.frame(table(vardata[vardata$spc=="Pp","sample_number"]))
summary(m_count_pf$Freq)
# Min. 1st Qu.  Median    Mean 3rd Qu.    Max. 
# 2.00    3.00    4.00    4.14    5.00    8.00 
summary(m_count_pp$Freq)
#  Min. 1st Qu.  Median    Mean 3rd Qu.    Max. 
# 1.000   3.000   4.000   4.383   5.000  10.000

# Some populations had >1 clone sequenced (pQBR57+ = "P", pQBR57-Tn5042+ = "T", pQBR57-Tn5042- = "0)
# Do these clones have different mutations?
# Get subset of vardata for just populations with >1 clone sequenced

vardata$pop <- factor(with(vardata, paste(plasmid_trt, cul, mer, rep, spc, sep=".")))

vardata$hit <- with(vardata, paste(paste(target, pop, sep="_")))

n_clones <- with(vardata, ddply(vardata, .(pop), function(x) length(unique(x$plasmid))))
n_clones <- subset(n_clones, V1>1)

vardata_1 <- subset(vardata, pop %in% n_clones$pop)
# Get list of targets not repeated within pop
# Ignore targets on plasmid as no populations had two plasmid+ clones from the same species
diff <- vardata_1[!duplicated(vardata_1$hit) &
                    !duplicated(vardata_1$hit, fromLast=TRUE) &
                    vardata_1$chr!="LN713926",]

nrow(diff)
# 58 incidents of differentially-hit targets within a population
# What targets were found in more than one population?
diff[duplicated(diff$target),c("target","plasmid","spc","position")]
#        target plasmid spc position
# 209 PFLU_0458       0  Pf   514555
# 213 PFLU_6004       P  Pf  6559931
# 246      flgH       P  Pp  4978561
# 270   PP_0021       T  Pp    25912
# 285 prophage2       T  Pp  3383563
# 308      fliM       P  Pp  4949997
# These are genes that were hit in one clone within a population but not in the other
#   and this pattern occurred in >1 population.

# Is it likely that these mutations are associated with their genotype (i.e. plasmid+ or plasmid-)?
# Check to see what other clones these mutations arose in

vardata[vardata$target=="fliM",] # appears only in two P+ clones
vardata[vardata$target=="flgH",] # appears in a number of P+ and P- clones
# note that fliM is a flagellar switch protein, so probably affecting same
# phenotype as flgH (flagellar L-ring precursor)
vardata[vardata$target=="PFLU_6004",] # appears in a number of P+ and P- clones
vardata[vardata$target=="PFLU_0458",] # appears only in two P- clones
# (doesn't appear in plasmid-free populations)
vardata[vardata$target=="prophage2",] # appears in only two P- clones
# (doesn't appear in plasmid-free populations)
vardata[vardata$target=="PP_0021",] # appears in a number of clones (some P+ some P-)
# (all Tn5042 insertions).

# This suggests that we can't detect any within-population variation
#  specifically associated with plasmid adaptation.
# Therefore one of the sequenced clones (plasmid+ where available) 
#  can probably represent the population.

# The above was done with locus-level variation
# Are there within-locus within-population polymorphisms?
diff2 <- vardata_1[!duplicated(with(vardata_1, paste(hit, position))) &
                     !duplicated(with(vardata_1, paste(hit, position)), fromLast=TRUE) &
                     vardata_1$chr!="LN713926",]

diff2[row.names(diff2)[!(row.names(diff2) %in% row.names(diff))],
      c("sample_number","plasmid","position","position.1","target","pop")]
#     sample_number plasmid position position.1 target               pop
# 152            78       P  4978190    4978190   flgH pQBR57.co.16.c.Pp
# 159            79       T  4978561    4978561   flgH pQBR57.co.16.c.Pp
# This shows that there were independent flgH mutations within one population

# 2. Permutational MANOVA -------------------------------------------------

# To investigate whether chromosomal mutations are statistically assocated with treatments
#   use PERMANOVA (Scanlan et al., 2015)
# To perform permutational MANOVA, must resolve nestedness in the data set
# Take one clone from populations with >1 sequenced clone (plasmid+)
# Just look at populations that began with the plasmid, as there is insufficient plasmid-free data

vardata$locus <- with(vardata, paste(chr, target, sep="_"))

vardata_single <- rbind(vardata[vardata$pop %in% n_clones$pop & vardata$plasmid=="P",],
                        vardata[!(vardata$pop %in% n_clones$pop),])

# make unique for each population
vardata_uniq <- unique(vardata_single[,c("cul","mer","plasmid_trt","rep","spc","chr","locus","pop")])
# note that this step doesn't remove any data

vardata_uniq_cln <- droplevels(subset(vardata_uniq, chr!="LN713926" & 
                                        plasmid_trt=="pQBR57"))

# First analyse Pf

pf <- droplevels(subset(vardata_uniq_cln, spc=="Pf"))
varpf <- data.frame(table(pf$pop, pf$locus))

varpf <- dcast(varpf, Var1 ~ Var2, value.var="Freq")
rownames(varpf) <- varpf$Var1
varpf <- varpf[,c(2:length(colnames(varpf)))]

varpf_names <- data.frame(pop = row.names(varpf))
trtpf <- merge(varpf_names, unique(pf[,c("pop","cul","mer")]), by="pop")

vdpf  <- vegdist(varpf, method="euclidean")

adonis(vdpf ~ cul * mer, trtpf, permutations = 10000)
#           Df SumsOfSqs MeanSqs F.Model      R2    Pr(>F)    
# cul        1     8.042  8.0417  3.3860 0.12672 9.999e-05 ***
# mer        1     6.042  6.0417  2.5439 0.09521 0.0009999 ***
# cul:mer    1     1.875  1.8750  0.7895 0.02955 0.7310269    
# Residuals 20    47.500  2.3750         0.74852              
# Total     23    63.458                 1.00000  
# No significant effect of the interaction

adonis(vdpf ~ cul + mer, trtpf, permutations = 10000)
#           Df SumsOfSqs MeanSqs F.Model      R2    Pr(>F)    
# cul        1     8.042  8.0417  3.4203 0.12672 9.999e-05 ***
# mer        1     6.042  6.0417  2.5696 0.09521     4e-04 ***
# Residuals 21    49.375  2.3512         0.77807              
# Total     23    63.458                 1.00000    

# Main effects of mercury and co-culture are significant

# However, an assumption of this test is that group dispersions are homogenous.
# Test this, 
#    i.e. does variance vary between treatments?
b <- betadisper(vdpf, interaction(trtpf$mer, trtpf$cul))
anova(b) 
#           Df Sum Sq Mean Sq F value Pr(>F)
# Groups     3 0.3141 0.10471  0.6431 0.5962
# Residuals 20 3.2560 0.16280   

# No it doesn't. Good

anova(betadisper(vdpf, trtpf$mer)) # p = 0.17
anova(betadisper(vdpf, trtpf$cul)) # p = 0.92

# Together this indicates that there is a difference between Pf single-species and co-culture treatments

# Now investigate P. putida

pp <- droplevels(subset(vardata_uniq_cln, spc=="Pp"))

varpp <- data.frame(table(pp$pop, pp$locus))
varpp <- dcast(varpp, Var1 ~ Var2, value.var="Freq")
rownames(varpp) <- varpp$Var1
varpp <- varpp[,c(2:length(colnames(varpp)))]
vdpp  <- vegdist(varpp, method="euclidean")

varpp_names <- data.frame(pop = row.names(varpp))
trtpp <- merge(varpp_names, unique(pp[,c("pop","cul","mer")]), by="pop")

adonis(vdpp ~ cul * mer, trtpp, permutations = 10000)
#           Df SumsOfSqs MeanSqs F.Model      R2 Pr(>F)
# cul        1     2.958  2.9583 0.86797 0.03783 0.7144
# mer        1     3.625  3.6250 1.06357 0.04635 0.3160
# cul:mer    1     3.458  3.4583 1.01467 0.04422 0.4034
# Residuals 20    68.167  3.4083         0.87160       
# Total     23    78.208                 1.00000  

adonis(vdpp ~ cul + mer, trtpp, permutations = 10000)
#           Df SumsOfSqs MeanSqs F.Model      R2 Pr(>F)
# cul        1     2.958  2.9583 0.86736 0.03783 0.7144
# mer        1     3.625  3.6250 1.06283 0.04635 0.3268
# Residuals 21    71.625  3.4107         0.91582       
# Total     23    78.208                 1.00000  

adonis(vdpp ~ mer, trtpp, permutations = 10000)
#           Df SumsOfSqs MeanSqs F.Model      R2 Pr(>F)
# mer        1     3.625  3.6250  1.0693 0.04635   0.34
# Residuals 22    74.583  3.3902         0.95365       
# Total     23    78.208                 1.00000   

anova(betadisper(vdpp, interaction(trtpp$mer, trtpp$cul)))
#           Df Sum Sq Mean Sq F value Pr(>F)
# Groups     3 0.5962 0.19873  0.8068 0.5049
# Residuals 20 4.9265 0.24632  
anova(betadisper(vdpp, trtpp$mer)) # p = 0.74
anova(betadisper(vdpp, trtpp$cul)) # p = 0.62

# Conclusion:
# - Detectible effect of mer and co-culture on P. fluorescens evolution
# - Co-culture effect is driven by actP, mer effect is more complex
# - No detectible mutational effect on P. putida.


# 2b. Same analysis but including all clones ------------------------------

# Here, resolve nestedness by taking all mutations detected within each population
vardata_uniq_2 <- unique(vardata[,c("cul","mer","plasmid_trt","rep","spc","chr","locus","pop")])
vardata_uniq_2_cln <- droplevels(subset(vardata_uniq_2, chr!="LN713926" & 
                                        plasmid_trt=="pQBR57"))

pf_2 <- droplevels(subset(vardata_uniq_2_cln, spc=="Pf"))
varpf_2 <- data.frame(table(pf_2$pop, pf_2$locus))
varpf_2 <- dcast(varpf_2, Var1 ~ Var2, value.var="Freq")
rownames(varpf_2) <- varpf_2$Var1
varpf_2 <- varpf_2[,c(2:length(colnames(varpf_2)))]
length(varpf); length(varpf_2) # including all clones increases size from 37 to 46 loci
varpf_2_names <- data.frame(pop = row.names(varpf_2))
trtpf_2 <- merge(varpf_2_names, unique(pf_2[,c("pop","cul","mer")]), by="pop")
vdpf_2  <- vegdist(varpf_2, method="euclidean")

adonis(vdpf_2 ~ cul * mer, trtpf_2, permutations = 10000)
#           Df SumsOfSqs MeanSqs F.Model      R2    Pr(>F)    
# cul        1     8.333  8.3333  2.9586 0.11364 9.999e-05 ***
# mer        1     6.333  6.3333  2.2485 0.08636    0.0018 ** 
# cul:mer    1     2.333  2.3333  0.8284 0.03182    0.6992    
# Residuals 20    56.333  2.8167         0.76818              
# Total     23    73.333                 1.00000   

adonis(vdpf_2 ~ cul + mer, trtpf_2, permutations = 10000)
#           Df SumsOfSqs MeanSqs F.Model      R2    Pr(>F)    
# cul        1     8.333  8.3333   2.983 0.11364 9.999e-05 ***
# mer        1     6.333  6.3333   2.267 0.08636    0.0012 ** 
# Residuals 21    58.667  2.7937         0.80000              
# Total     23    73.333                 1.00000       

b <- betadisper(vdpf_2, interaction(trtpf_2$mer, trtpf_2$cul))
anova(b)
#           Df Sum Sq  Mean Sq F value Pr(>F)
# Groups     3 0.0364 0.012133  0.0753 0.9726
# Residuals 20 3.2235 0.161174    

# qualitatively similar result

# Now investigate P. putida
pp_2 <- droplevels(subset(vardata_uniq_2_cln, spc=="Pp"))
varpp_2 <- data.frame(table(pp_2$pop, pp_2$locus))
varpp_2 <- dcast(varpp_2, Var1 ~ Var2, value.var="Freq")
rownames(varpp_2) <- varpp_2$Var1
varpp_2 <- varpp_2[,c(2:length(colnames(varpp_2)))]
vdpp_2  <- vegdist(varpp_2, method="euclidean")

varpp_2_names <- data.frame(pop = row.names(varpp_2))
trtpp_2 <- merge(varpp_2_names, unique(pp_2[,c("pop","cul","mer")]), by="pop")

adonis(vdpp_2 ~ cul * mer, trtpp_2, permutations = 10000)
#           Df SumsOfSqs MeanSqs F.Model      R2  Pr(>F)  
# cul        1     3.750  3.7500 0.91093 0.03937 0.63814  
# mer        1     5.250  5.2500 1.27530 0.05512 0.08359 .
# cul:mer    1     3.917  3.9167 0.95142 0.04112 0.53915  
# Residuals 20    82.333  4.1167         0.86439          
# Total     23    95.250                 1.00000       

adonis(vdpp_2 ~ cul + mer, trtpp_2, permutations = 10000)
#           Df SumsOfSqs MeanSqs F.Model      R2  Pr(>F)  
# cul        1      3.75  3.7500 0.91304 0.03937 0.63034  
# mer        1      5.25  5.2500 1.27826 0.05512 0.08099 .
# Residuals 21     86.25  4.1071         0.90551          
# Total     23     95.25                 1.00000   

adonis(vdpp_2 ~ mer, trtpp_2, permutations = 10000)
#           Df SumsOfSqs MeanSqs F.Model      R2  Pr(>F)  
# mer        1      5.25  5.2500  1.2833 0.05512 0.08659 .
# Residuals 22     90.00  4.0909         0.94488          
# Total     23     95.25                 1.00000 

anova(betadisper(vdpp_2, interaction(trtpp_2$mer, trtpp_2$cul)))
#           Df Sum Sq Mean Sq F value Pr(>F)
# Groups     3 1.3168 0.43892  1.4843 0.2491
# Residuals 20 5.9140 0.29570     
anova(betadisper(vdpp_2, trtpp_2$mer)) # p = 0.85
anova(betadisper(vdpp_2, trtpp_2$cul)) # p = 0.10

# Qualitatively similar results obtained when collecting all mutations across a population
#   and analysing a single clone from that population


# 3. Identification of parallel and treatment-specific mutations ----------

# Look for mutations appearing in parallel in different populations
# Here, look at all mutations appearing within a population (i.e. over both clones where present) 
#   to maximise power

vardata_u <- unique(vardata[,c("plasmid_trt","cul","mer","rep","spc","locus","pop")])

vardata_u_tab <- data.frame(table(locus=vardata_u[,c("locus")]))
vardata_u_tab[with(vardata_u_tab, order(Freq)), ]

count(vardata_u_tab$Freq)
#  x freq
#  1  134
#  2   18
#  3    5
#  4    4
#  5    1
#  6    4
#  9    1
# 10    1
# 11    3
# 14    1
# 17    1
# 19    1

parallel_mut <- vardata_u_tab[vardata_u_tab$Freq>1,]
nrow(parallel_mut)
# 40 putative parallel mutations found across all clones, including plasmid

# Get treatment info for each mutation
# highlight where it was identified as treatment specific and include p values
vardata_u$trt <- with(vardata_u, paste(plasmid_trt, cul, mer, sep="."))
parallel_mut_tab_all <- data.frame(table(vardata_u[,c("locus","trt")]))
parallel_mut_tab_all <- dcast(parallel_mut_tab_all, locus ~ trt, value.var="Freq")
parallel_mut_tab_all$tot <- rowSums(parallel_mut_tab_all[,c(2:length(parallel_mut_tab_all))])

parallel_mut_tab_all <- subset(parallel_mut_tab_all, tot>1)

# ParallelTargets describes the parallel mutations occurring in each treatment
# It was modified manually to give the Supplementary Table
write.table(parallel_mut_tab_all, file="ParallelTargets.tsv", sep="\t", quote=FALSE, row.names=FALSE)


# Investigate the different treatments
# Candidate treatment-specific parallel mutations occur >1 in a treatment
#   and do not occur in the alternative treatment

parallel_mut_cln <- subset(data.frame(table(locus=vardata_u[,c("locus")])),
                        Freq>1)

trtMuts <- function(x,df) {
  d <- subset(df, locus==x)
  df <- data.frame(with(d, table(cul,mer,plasmid_trt)))
  ddply(df, .(cul), function(x) sum(x$Freq))
  ss <- sum(df[df$cul=="ss","Freq"])
  co <- sum(df[df$cul=="co","Freq"])
  mer0 <- sum(df[df$mer==0,"Freq"])
  mer16 <- sum(df[df$mer==16,"Freq"])
  pQBR57 <- sum(df[df$plasmid_trt=="pQBR57","Freq"])
  pfree <- sum(df[df$plasmid_trt=="plasmid-","Freq"])
  df$locus <- x
  df_out <- data.frame(ss=ss, co=co, mer0=mer0, mer16=mer16, pQBR57=pQBR57, pfree=pfree)
  return(df_out)
}

parallel_mut_tab <- adply(parallel_mut_cln, .margins=1, function(x) trtMuts(x$locus, df=vardata_u))

# consider treatment-specific parallel mutations as those occuring >1 in one level of treatment
# and 0 times in the other.
parallel_mut_tab$candidate <- with(parallel_mut_tab, ifelse(((ss>1 & co==0) | (ss==0 & co>1) |
                                                        (mer0>1 & mer16==0) | (mer0==0 & mer16>1) |
                                                        (pQBR57>1 & pfree==0) | (pQBR57==0 & pfree>1)),
                                                        1,0))
# Look at chromosomal mutations only since plasmid mutations may be pseudoreplicated 
#   within populations (same mutation appearing in different species)
parallel_mut_chr <- parallel_mut_tab[grep("LN713926", parallel_mut_tab$locus, invert=TRUE),]
sum(parallel_mut_chr$candidate) # 23 candidates
nrow(parallel_mut_chr) # (31 parallel genes in total)

# Test all parallel mutations
parallel_mut_chrc <- parallel_mut_chr

# number of populations with sequencing for each treatment
pops <- unique(vardata_u[,c("plasmid_trt","cul","mer","rep")])
data.frame(table(pops$cul, pops$mer, pops$plasmid_trt))

testFisher <- function(x) {
  # number of populations with sequencing varies for each level of each treatment
  # numbers of populations with sequencing is the same for both species
  n_ss <- 18
  n_co <- 16  
  n_mer <- 17
  n_pQ <- 24
  n_pfree <- 10
  cul_test <- matrix(c(x$ss, n_ss-x$ss, x$co, n_co-x$co),
                     nrow=2, dimnames=list(c("mutated","wt"),
                                           c("ss","co")))
  mer_test <- matrix(c(x$mer0, n_mer-x$mer0, x$mer16, n_mer-x$mer16),
                     nrow=2, dimnames=list(c("mutated","wt"),
                                           c("mer0","mer16")))
  pq_test <- matrix(c(x$pQBR57, n_pQ-x$pQBR57, x$pfree, n_pfree-x$pfree),
                     nrow=2, dimnames=list(c("mutated","wt"),
                                           c("pQBR57","pfree")))
  cul_test_results <- fisher.test(cul_test)
  mer_test_results <- fisher.test(mer_test)
  pq_test_results <- fisher.test(pq_test)
  df <- data.frame(cul.p = cul_test_results$p.value,
                   mer.p = mer_test_results$p.value,
                   pq.p  = pq_test_results$p.value)
  return(df)
}

parallel_mut_chrc <- adply(parallel_mut_chrc, .margins=1, function(x) testFisher(x))
n_tests <- 3 * sum(parallel_mut_chr$candidate)
bonferroni_adjusted <- 0.05/(n_tests)

parallel_mut_chrc$sig <- with(parallel_mut_chrc, ifelse(cul.p<0.05 |
                                                        mer.p<0.05 |
                                                        pq.p<0.05,
                                                        "*",""))
parallel_mut_chrc$sig.adj <- with(parallel_mut_chrc, ifelse(cul.p<bonferroni_adjusted |
                                                            mer.p<bonferroni_adjusted |
                                                            pq.p<bonferroni_adjusted,
                                                            "*",""))

write.table(parallel_mut_chrc[,c("locus","cul.p","mer.p","pq.p","sig","sig.adj")],
            "fisher_test_results.tsv", sep="\t", row.names=FALSE, quote=FALSE)

# This gives a Bonferroni-corrected result, 
# However, this can inflate Type II error.
# Sequential Bonferroni (Holm-Bonferroni) is less conservative

p_hb <- melt(parallel_mut_chrc[parallel_mut_chrc$candidate==1,c("locus","cul.p","mer.p","pq.p")],
             measure.vars = c("cul.p","mer.p","pq.p"),
             value.name = "p", variable.name = "test")
p_hb <- p_hb[with(p_hb, order(p)),]
p_hb$number <- 1:(nrow(p_hb))
num_tests <- nrow(p_hb)
p_hb$alpha <- 0.05/(num_tests - p_hb$number + 1)
p_hb$sig <- ifelse(p_hb$p<p_hb$alpha, "*", "")
p_hb$p_adj <- with(p_hb, p * (num_tests - number + 1))
p_hb$p_adj <- ifelse(p_hb$p_adj > 1, 1, p_hb$p_adj)
p_hb
p_hb_wide <- dcast(p_hb[,c("locus","test","p_adj")], locus ~ test)
p_hb_wide <- p_hb_wide[with(p_hb_wide, order(locus)), ]
write.table(p_hb,
            "fisher_test_results_HB.tsv", sep="\t", row.names=FALSE, quote=FALSE)

# Significant results are actP, associated with culture
# marginal results (not significant following Bonferroni correction) are 
# - katA in Pf, associated with absence of pQBR57 and occurs only in mercury treatments.
# - katA in Pp, similar to above.
# - PP_0021, associated with mercury.
#     A common target of Tn5042 insertion.
# - PFLU_4242, associated with presence of pQBR57 and presence of mercury.
#     Gene putatively involved in plasmid cost.

# These data are summarized in Supplementary Table 1


# To test whether the statistical association between co-culture and genome evolution
#   detected by PERMANOVA analysis is driven by actP

# Test by randomizing actP column and testing for effect
actp <- varpf[,"AM181176_actP"]
varpf_actp <- varpf
# randomize actp column
varpf_actp[,"AM181176_actP"] <- sample(actp)

vdpf_actp  <- vegdist(varpf_actp, distance="euclidean")
adonis(vdpf_actp ~ cul + mer, trtpf, permutations = 10000)

#           Df SumsOfSqs MeanSqs F.Model      R2 Pr(>F)   
# cul        1    0.4951 0.49511  1.7700 0.06635 0.1062   
# mer        1    1.0931 1.09311  3.9079 0.14648 0.0017 **
# Residuals 21    5.8741 0.27972         0.78717          
# Total     23    7.4624                 1.00000  

# Randomizing actP data across populations removes effect of culture

anova(betadisper(vdpf_actp, interaction(trtpf$mer, trtpf$cul))) # p = 0.44
anova(betadisper(vdpf_actp, trtpf$cul)) # p = 0.80

# no more effect of co-culture, suggesting that actP was driving effect.
# (Randomization was repeated several times, this effect was consistent).

# Removal of actP from the dataset has a similar effect
colnames(varpf)
varpf_noactp <- varpf[,2:length(colnames(varpf))]

vdpf_noactp  <- vegdist(varpf_noactp, method="euclidean")
adonis(vdpf_noactp ~ cul + mer, trtpf, permutations = 10000)
#           Df SumsOfSqs MeanSqs F.Model      R2 Pr(>F)   
# cul        1       3.0  3.0000  1.2990 0.05217 0.1584   
# mer        1       6.0  6.0000  2.5979 0.10435 0.0011 **
# Residuals 21      48.5  2.3095         0.84348          
# Total     23      57.5                 1.00000    
anova(betadisper(vdpf_noactp, interaction(trtpf$mer, trtpf$cul))) # p = 0.4546
anova(betadisper(vdpf_noactp, trtpf$cul)) # p = 0.8212
anova(betadisper(vdpf_noactp, trtpf$mer)) # p = 0.1726



# 3b. Same analysis but including just single clones/population ------------------------------

parallel_mut_cln_2 <- subset(data.frame(table(locus=vardata_single[,c("locus")])),
                           Freq>1)

parallel_mut_tab_2 <- adply(parallel_mut_cln_2, .margins=1, 
                            function(x) trtMuts(x$locus, df=vardata_single))

parallel_mut_tab_2$candidate <- with(parallel_mut_tab_2, 
                                     ifelse(((ss>1 & co==0) | (ss==0 & co>1) |
                                               (mer0>1 & mer16==0) | (mer0==0 & mer16>1) |
                                               (pQBR57>1 & pfree==0) | (pQBR57==0 & pfree>1)),
                                            1,0))
# Look at chromosomal mutations only since plasmid mutations may be pseudoreplicated 
#   within populations
parallel_mut_chr_2 <- parallel_mut_tab_2[grep("LN713926", parallel_mut_tab_2$locus, invert=TRUE),]
sum(parallel_mut_chr_2$candidate) # 21 candidates

parallel_mut_chr[which(!(parallel_mut_chr$locus %in% parallel_mut_chr_2$locus)),]
# Using just one clone/population removes prophage 2 or PFLU_0458 from list of parallel targets
testFisher(parallel_mut_chr[parallel_mut_chr$locus=="AE015451_prophage2",])
#     cul.p     mer.p pq.p
# 0.2139037 0.4848485    1
testFisher(parallel_mut_chr[parallel_mut_chr$locus=="AM181176_PFLU_0458",])
#  cul.p     mer.p pq.p
#      1 0.4848485    1
# neither of which were significant

# No qualitative difference when including all clones or just the plasmid-containing clone
