##### Analysis of growth rates ±P. putida data #####
# J. P. J. Hall, August 2018

rm(list=ls())
source("~/.Rprofile")
# Loads summarySE function available here http://www.cookbook-r.com/Manipulating_data/Summarizing_data/
library(ggplot2)
library(grid)
library(car)

data3 <- read.table("./data/SuppTab5.csv",
                    sep=",", header=TRUE)
head(data3)

xtabs(~data3$evo_rep+data3$evo_mer+data3$cul)

# Growth tests were done using sequenced clones, and replicated for each sample 3 or 4 times
# Only three replicates for co-cultured d, and for single-species e. 

data3$pop <- factor(with(data3, paste(evo_rep, evo_mer, pla_trt, cul, sep=".")))
table(data3$pop, data3$tech_rep) 

# Make a linear model with
#    fixed effects: actp_status
#    random effects: clone
#    response: w

# Analyse W, i.e. the ratio of m.with_putida / m.alone

# Pre-model diagnostics
par(mfrow=c(1,1))
boxplot(data3$w ~ data3$actp_status)
bartlett.test(x = data3$w, g = data3$actp_status) # Bartlett's is ok (p = 0.4526)
fligner.test(x = data3$w, g = data3$actp_status) # fligner is ok (p = 0.7164)
leveneTest(data3$w ~ data3$actp_status) # levene's is ok (p = 0.974)

library(nlme)

M1 <- gls(w ~ actp_status,
          method="REML", data=data3)
M2 <- lme(w ~ actp_status, random = ~1|cln_name,
            method="REML", data=data3)
anova(M1, M2)
# models are similar
max(ranef(M2)) # 1.17458e-08
# not much variability explained by difference between clones

M2.ml <- lme(w ~ actp_status, random = ~1|cln_name,
          method="ML", data=data3)
drop1(M2.ml, test="Chisq")
# Single term deletions
# 
# Model:
#   w ~ actp_status
#             Df     AIC    LRT  Pr(>Chi)    
# <none>         -245.56                     
# actp_status  1 -235.53 12.034 0.0005225 ***

qqPlot(residuals(M2)) # qq-plot looks ok
shapiro.test(residuals(M2)) # W = 0.97414, p-value = 0.07539
data3$resid <- resid(M2, type="normalized")
ggplot(data=data3, aes(x=actp_status, y=resid)) + geom_boxplot()
# looks good

fixef(M2)
# (Intercept) actp_statuswild-type 
#  0.90664897           0.04789924 
# So the ratio of with_putida/alone is higher for wild-type than for disrupted actP.
#    actP status has a significant effect on growth without putida compared to with putida

# Is this driven by increased growth in absence, decreased growth in presence, or both?
# Analyse growth rates m for clones grown alone
bartlett.test(x = data3$m.alone, g = data3$actp_status) # Bartlett's is ok (p = 0.3262)
fligner.test(x = data3$m.alone, g = data3$actp_status) # fligner is ok (p = 0.18473)
leveneTest(data3$m.alone ~ data3$actp_status) # levene's is ok (p = 0.5168)
M3.lm <- lm(m.alone ~ actp_status, data=data3)
qqPlot(residuals(M3.lm))
shapiro.test(residuals(M3.lm)) # Shapiro-Wilk is marginal but ok (p-value = 0.08833)

# Include clone as random effect (as above)
M3.ml <- lme(m.alone ~ actp_status, random=~1|cln_name,
             data=data3, method="ML")
drop1(M3.ml, test="Chisq")
#             Df    AIC    LRT Pr(>Chi)  
# <none>         67.660                  
# actp_status  1 70.733 5.0727  0.02431 *

# So actp_status has an effect on growth when clones are grown alone
M3.REML <- update(M3.ml, method="REML")

fixef(M3.REML)
# (Intercept) actp_statuswild-type 
#   5.2148261           -0.2335276 
# with wild-type growing slower.


# Now analyse growth rates m for clones grown in co-culture
bartlett.test(x = data3$m.with_putida, g = data3$actp_status) # Bartlett's is ok (p = 0.7257)
fligner.test(x = data3$m.with_putida, g = data3$actp_status) # fligner is ok (p = 0.9956)
leveneTest(data3$m.with_putida ~ data3$actp_status) # levene's is ok (p = 0.8525)
M4.lm <- lm(m.with_putida ~ actp_status, data=data3)
qqPlot(residuals(M4.lm))
shapiro.test(residuals(M4.lm)) # no good (p = 0.00165)
library(pastecs)
t(t(stat.desc(residuals(M4.lm), norm=TRUE)))
# Exhibits both kurtosis and skew
# requires transformation

library(MASS)
boxcox(m.with_putida ~ actp_status, data=data3, lambda=seq(0,7,0.5))
# estimate at 4

data3$m.with_putida.boxcox <- with(data3, (((m.with_putida)^4)-1)/4)
bartlett.test(x = data3$m.with_putida.boxcox, g = data3$actp_status) # Bartlett's is ok (p = 0.8276)
fligner.test(x = data3$m.with_putida.boxcox, g = data3$actp_status) # fligner is ok (p = 0.9211)
leveneTest(data3$m.with_putida.boxcox ~ data3$actp_status) # levene's is ok (p = 0.9236)
M4bc.lm <- lm(m.with_putida.boxcox ~ actp_status, data=data3)
qqPlot(residuals(M4bc.lm))
shapiro.test(residuals(M4bc.lm)) # p = 0.7219, good!

M4bc <- lme(m.with_putida.boxcox ~ actp_status, random=~1|cln_name,
          data=data3, method="REML")
M4bc.ml <- lme(m.with_putida.boxcox ~ actp_status, random=~1|cln_name,
             data=data3, method="ML")
drop1(M4bc.ml, test="Chisq")
# Single term deletions
# 
# Model:
#   m.with_putida.boxcox ~ actp_status
# Df    AIC     LRT Pr(>Chi)
# <none>         895.74                 
# actp_status  1 893.78 0.03547   0.8506


# no effect of actp status when grown in co-culture

# Check that result for M3 also holds with box-cox transformed data
data3$m.alone.boxcox <- with(data3, (((m.alone)^4)-1)/4)
bartlett.test(x = data3$m.alone.boxcox, g = data3$actp_status) # Bartlett's is ok (p = 0.06418)
fligner.test(x = data3$m.alone.boxcox, g = data3$actp_status) # Fligner is ok (p = 0.2064)
leveneTest(data3$m.alone.boxcox ~ data3$actp_status) # Levene's is ok (p = 0.188)
M3bc.lm <- lm(m.alone.boxcox ~ actp_status, data=data3)
qqPlot(residuals(M3bc.lm))
shapiro.test(residuals(M3bc.lm)) # Shapiro-Wilk is ok (0.2108)

M3bc <- lme(m.alone.boxcox ~ actp_status, random=~1|cln_name,
          data=data3, method="REML")
M3bc.ml <- lme(m.alone.boxcox ~ actp_status, random=~1|cln_name,
             data=data3, method="ML")
drop1(M3bc.ml, test="Chisq")
# Single term deletions
# 
# Model:
#   m.alone.boxcox ~ actp_status
#             Df    AIC    LRT Pr(>Chi)  
# <none>         923.70                  
# actp_status  1 926.97 5.2681  0.02172 *

# So yes, the result holds.

# Therefore, these models suggest that actP mutants have a growth benefit 
#   in the absence of P. putida
#     but don't suffer a detectable growth cost in the presence of P. putida


# Preliminary analysis into effect of different mutational types

data3$effect_code <- factor(ifelse(is.na(data3$impact), "0",
                            as.character(data3$impact)))

M5.ml <- lme(w ~ effect_code, random=~1|cln_name, method="ML",
         data=subset(data3, actp_status=="mutated"))
plot(M5.ml)
drop1(M5.ml, test="Chisq")
#             Df     AIC    LRT Pr(>Chi)
# <none>         -110.68                
# effect_code  3 -113.14 3.5437   0.3151

# Cannot detect a significant effect of the different mutational types
