##### Analysis of density data from long-term soil experiment #####
# J. P. J. Hall, August 2018

rm(list=ls())
source("~/.Rprofile")

dat <- read.table("./data/SuppTab6.csv",
                  header=TRUE, sep=",")

# Interested in P. fluorescens only
dat <- subset(dat, spc=="Pf")

# remove t=0 because it's low due to starting inoculation
dat <- subset(dat, tra > 0) 
head(dat)

# Remove all points with no data
dat <- subset(dat, tot > 0)

# Remove replicate b, single-species plasmid-free in mercury, since this one died out
dat <- subset(dat, !(rep=="b" & spc=="Pf" & cul=="ss" & pla_trt=="plasmid-" & mer=="16"))

# Mercury is a factor
dat$mer <- as.factor(dat$mer)

# quick plot
library(ggplot2)

ggplot(data=dat, aes(x=tra, y=tot, colour=cul, linetype=pla_trt, 
                     group=interaction(rep,spc,pla_trt,mer,cul))) +
  geom_line() + facet_grid(mer~cul, scales="free")

ggplot(data=dat, aes(x=tra, y=log(tot, base=10), colour=cul, linetype=pla_trt, 
                     group=interaction(rep,spc,pla_trt,mer,cul))) +
  geom_line() + facet_grid(mer~cul, scales="free")

# Simple model, fitting straight lines to data

dat<-within(dat, {
  groups<-interaction(cul, tra, pla_trt, mer)
  groups<-reorder(groups, tot, mean)
})

mod1 <- lm(tot ~ cul * tra * pla_trt * mer, data=dat)
par(mfrow=c(2,2))
plot(mod1) # possible issue with increasing variance

bartlett.test(dat$tot, g=dat$groups)
fligner.test(dat$tot, g=dat$groups)
shapiro.test(resid(mod1))
# none of these look good

dat$log.tot <- log(dat$tot, base=10)
mod11 <- lm(log.tot ~ cul * tra * pla_trt * mer, data=dat)
par(mfrow=c(2,2))
plot(mod11)

bartlett.test(dat$log.tot, g=dat$groups) # 9.712e-08
fligner.test(dat$log.tot, g=dat$groups) # 0.06603
shapiro.test(resid(mod11)) # 9.245e-08
# none of these look good either

# Box-Cox transformation
library(MASS)
par(mfrow=c(1,1))
boxcox(log.tot ~ tra * pla_trt * cul * mer, data=dat, lambda=seq(0,20,0.1))
boxcox(log.tot ~ tra * pla_trt * cul * mer, data=dat, lambda=seq(5,15,0.1))
# estimate at 8
lbd <- 8
dat$log.tot.boxcox<-(((dat$log.tot)^lbd)-1)/lbd

mod2 <- lm(log.tot.boxcox ~ cul * tra * pla_trt * mer, data=dat)
par(mfrow=c(2,2))
plot(mod2) # possibly better
bartlett.test(dat$log.tot.boxcox, g=dat$groups) # p = 0.002526. Note Bartlett's is sensitive to outliers
fligner.test(dat$log.tot.boxcox, g=dat$groups)  # p = 0.3384
shapiro.test(residuals(mod2)) # 0.009494
library(car)
par(mfrow=c(1,1))
qqPlot(resid(mod2)) # looks good, though Shapiro-Wilks test is off
# Note that as number of data points increases, likelihood of SW being significant also increases.
# Here we are looking at 794 points
library(pastecs)
stat.desc(residuals(mod2), norm=TRUE)
# So an improvement on non-transformed data, but showing significant kurtosis
# This is investigated below.

# Note that this simple model doesn't account for correlation in the data (repeated measures)
# Investigate more complex mixed-effects model 
# Plot out for each population to assess random effects

dat$fixef<-as.factor(with(dat, paste(pla_trt, cul, mer, sep=".")))
dat$pop<-as.factor(with(dat, paste(rep, pla_trt, spc, cul, mer, sep=".")))

ggplot(data=dat, aes(x=tra, y=log.tot.boxcox)) +
  geom_point() +
  facet_grid(rep~fixef)

# Fit models both with and without random effects of population to test for their effect
library(nlme)
mod.gls.reml.01<-gls(log.tot.boxcox ~ tra * pla_trt * cul * mer, 
                     method="REML", data=dat)
mod.lmm.reml.01<-lme(log.tot.boxcox ~ tra * pla_trt * cul * mer, 
                     random = ~tra|pop, method="REML", data=dat)
anova(mod.gls.reml.01, mod.lmm.reml.01)

#                 Model df      AIC      BIC    logLik   Test      L.Ratio p-value
# mod.gls.reml.01     1 17 22758.04 22837.20 -11362.02                            
# mod.lmm.reml.01     2 20 22764.04 22857.17 -11362.02 1 vs 2 2.810106e-06       1
# Testing on the boundary:
loglik <- 2*(c(logLik(mod.lmm.reml.01)-logLik(mod.gls.reml.01)))
0.5 * (1 - pchisq(loglik, 1))
# p = 0.5
# Random effects almost certainly not significant
# However since these repeated measures are part of sampling structure, keep them in

# Refit model with ML

mod.lmm.01 <- lme(log.tot.boxcox ~ tra * pla_trt * cul * mer, 
                  random = ~tra|pop, method="ML", data=dat)
stepAIC(mod.lmm.01, test="Chisq")

# log.tot.boxcox ~ tra + pla_trt + cul + mer + tra:pla_trt + tra:cul +      
#          pla_trt:cul + tra:mer + pla_trt:mer + tra:pla_trt:mer 

mod.lmm.02 <- lme(log.tot.boxcox ~ tra + pla_trt + cul + mer + tra:pla_trt + tra:cul +      
                              pla_trt:cul + tra:mer + pla_trt:mer + tra:pla_trt:mer, 
                  random = ~tra|pop, method="ML", data=dat)
drop1(mod.lmm.02, test="Chisq")
#                 Df   AIC     LRT Pr(>Chi)   
# <none>             23040                    
# tra:cul          1 23048 10.0064  0.00156 **
# pla_trt:cul      1 23041  3.0000  0.08326 . 
# tra:pla_trt:mer  1 23043  5.1847  0.02279 *  

mod.lmm.03 <- update(mod.lmm.02, .~.-pla_trt:cul)
drop1(mod.lmm.03, test="Chisq")
#                 Df   AIC    LRT Pr(>Chi)   
# <none>             23041                   
# tra:cul          1 23049 9.9465 0.001612 **
# tra:pla_trt:mer  1 23044 5.1624 0.023081 * 

# Plot main effects of co-culture to examine
ggplot(data=dat, aes(x=cul, y=log.tot.boxcox)) + geom_boxplot() + theme_bw()
# Remove interaction term to examine main effect of co-culture
mod.lmm.04 <- update(mod.lmm.03, .~.-tra:cul)
drop1(mod.lmm.04, test="Chisq")
#                 Df   AIC     LRT  Pr(>Chi)    
# <none>             23049                      
# cul              1 23071 24.2204 8.592e-07 ***
# tra:pla_trt:mer  1 23052  5.4332   0.01976 *
# significant effects of co-culture

# Refit model with REML
mod.lmm.03.REML <- update(mod.lmm.03, .~., method="REML")

anova(mod.lmm.03.REML)
#                 numDF denDF  F-value p-value
# (Intercept)         1   742 40907.47  <.0001
# tra                 1   742   527.61  <.0001
# pla_trt             1    42    50.99  <.0001
# cul                 1    42    42.98  <.0001
# mer                 1    42   291.67  <.0001
# tra:pla_trt         1   742     5.34  0.0212
# tra:cul             1   742     9.93  0.0017
# tra:mer             1   742     3.52  0.0610
# pla_trt:mer         1    42   126.14  <.0001
# tra:pla_trt:mer     1   742     5.11  0.0240

t(t(round(fixef(mod.lmm.03.REML))))
# (Intercept)             3196791
# tra                       19128
# pla_trtpQBR57             75597
# culss                     65458
# mer16                   -954938
# tra:pla_trtpQBR57         -7794
# tra:culss                  5282
# tra:mer16                  -776
# pla_trtpQBR57:mer16      571203
# tra:pla_trtpQBR57:mer16    7599

plot(mod.lmm.03.REML)

# investigate possible kurtosis
dat$resid <- resid(mod.lmm.03.REML, type="normalized")
qqPlot(dat$resid) # still outliers
shapiro.test(dat$resid) # p-value = 0.008242
stat.desc(dat$resid, norm=TRUE) 
# Non-normality due to kurtosis, not skew, though examining qqplot suggests this is slight
#  and may be due to large number of data points
# Compare residuals with normal distribution. 
ggplot(data=dat, aes(resid)) + geom_histogram(aes(y=..density..), colour="black", fill="white") +
  stat_function(fun=dnorm, args=list(mean=mean(dat$resid), sd=sd(dat$resid)), colour="black", size=1)
# Suggests kurtosis is negligible.
ks.test(dat$resid, y="pnorm") # not significantly different from normal
# according to Kolmogorov-Smirnov (p = 0.4942)

dat$fitted <- fitted(mod.lmm.03.REML)
library(grid)
grid.newpage()
pushViewport(viewport(layout=grid.layout(2,2))) 
print((ggplot(data=dat, aes(x=fitted, y=resid)) + geom_point()),
      vp=viewport(layout.pos.col=1,layout.pos.row=1))
print((ggplot(data=dat, aes(x=mer, y=resid)) + geom_boxplot()),
      vp=viewport(layout.pos.col=2,layout.pos.row=1))
print((ggplot(data=dat, aes(x=cul, y=resid)) + geom_boxplot()),
      vp=viewport(layout.pos.col=1,layout.pos.row=2))
print((ggplot(data=dat, aes(x=pla_trt, y=resid)) + geom_boxplot()),
      vp=viewport(layout.pos.col=2,layout.pos.row=2))
ggplot(data=dat, aes(x=tra, y=resid)) + geom_point()
# There is some heterogeneity across transfers, but no overall trend

# Interpretation:
# tra:pla_trtpQBR57:mer
#    = there is an extra boost to growth under mercury and plasmid, than expected by each factor alone
# pla_trtpQBR57:mer     
#    = under mercury, plasmid-carrying Pf are at higher density than would be expected
# tra:mer               = not significant (suggests that increases are reduced in mercury)
# tra:culss             = *** single-species Pf increase in total density faster
# tra:pla_trtpQBR57     = plasmid-free Pf increase in total density faster
# mer                   = mercury reduces total density
#   (though note that this main effect cannot be well interpreted in the presence of the interaction)
# cul                   = single-species Pf are higher density, 
#   (though note that this main effect cannot be well interpreted in the presence of the interaction)
# pla_trt               = plasmid-containing Pf are higher density
# tra                   = increases in density over course of experiment

dat$fitted <- fitted(mod.lmm.03.REML)
ggplot(data=dat, aes(x=tra, y=log.tot.boxcox)) +
  geom_point() +
  geom_line(aes(x=tra, y=fitted), colour="red") +
  facet_grid(rep~fixef)

# Model fit looks ok

# Effect on Pf of co-culture
#            effect size = 5282
# tra:cul, LRT, Chisq(1) = 10.0064, p = 0.00156 
# Cannot meaningfully interpret significance of main effect of co-culture in a model with interactions
# Fitted a mixed effects models with population as a random effect on intercept and slope
# Response variable was Box-Cox log[10] transformed total density,
#   independent variables were transfer number, plasmid, culture, mercury and all interactions
# Reduction from a full model containing all parameters by removing one parameter at a time
#   and testing for significant changes in model fit by Chi-Squared goodness-of-fit tests (LRT).
