##### Analysis of acetate minimal media growth in selected soil-evolved clones #####
# J. P. J. Hall, August 2018

rm(list=ls())

library(ggplot2)

d2 <- read.table("./data/SuppTab7.csv",
                header=TRUE, sep=",")

# Analysis
# First attempt a basic linear model
library(nlme)
g <- factor(d2$actp.status)

bartlett.test(x = d2$media_ratio, g = g) # 0.03538
fligner.test(x = d2$media_ratio, g = g)  # 0.4668
library(car)
leveneTest(d2$media_ratio ~ d2$actp.status) # 0.2273

mod00 <- lm(data=d2, media_ratio ~ actp.status)
qqPlot(residuals(mod00))
shapiro.test(residuals(mod00)) # 6.217e-05

# So data is homoscedastic according to 2 out of 3 measures
# But non-normal residuals
# Try transformation

library(MASS)
boxcox(media_ratio ~ actp.status, data=d2, lambda=seq(-5,2,0.5))
lbd <- -2

d2$media_ratio.boxcox <- (((d2$media_ratio)^lbd)-1)/lbd
bartlett.test(x = d2$media_ratio.boxcox, g = g) # 0.02076
fligner.test(x = d2$media_ratio.boxcox, g = g)  # 0.125
leveneTest(d2$media_ratio.boxcox ~ d2$actp.status) # 0.08792

mod01 <- lm(data=d2, media_ratio.boxcox ~ actp.status)
qqPlot(residuals(mod01))
shapiro.test(residuals(mod01)) # 0.05967
library(pastecs)
stat.desc(residuals(mod01), norm=TRUE)

par(mfrow=c(2,2))
plot(mod01)
# Possible heteroscedasticity in residuals (consistent with Bartlett test above)
# So interpret model results carefully

anova(mod01)
# Response: media_ratio.boxcox
#             Df Sum Sq Mean Sq F value Pr(>F)
# actp.status  1 0.2228 0.22281  1.9137 0.1711
# Residuals   67 7.8008 0.11643  
# Suggests no effect of actp status

# Create mixed effects model to test

mod0 <- gls(media_ratio.boxcox ~ actp.status,
            method="REML", data=d2)
mod1 <- lme(media_ratio.boxcox ~ actp.status,
            random= ~1|cln_name,
            data=d2, method="REML")
anova(mod0,mod1)
# Correct for testing on boundary
loglik <- 2*(c(logLik(mod1)-logLik(mod0)))
0.5 * (1 - pchisq(loglik, 1))
# random effect of clone highly significant p = 1.103451e-12

ranef(mod1)

mod1_ml <- update(mod1, .~., method="ML")
drop1(mod1_ml, test="Chisq")
#             Df    AIC     LRT Pr(>Chi)
# <none>         6.0457                 
# actp.status  1 4.8050 0.75931   0.3835

plot(mod1)
# The residuals of the mixed effect model look much better than the simple model
d2$resid <- resid(mod1, type="normalized")
ggplot(data=d2, aes(x=actp.status, y=resid, group=cln_name)) + 
  geom_point(position=position_dodge(width=0.2))
par(mfrow=c(1,1))
qqPlot(d2$resid)
# the mixed effects model is valid

# Summary: no significant effect of actp status: LRT Chisq(1) = 0.75931, p = 0.3835.
# Check for consistency with non-parametric Wilcoxon test

d2_summ <- summarySE(d2, measurevar="media_ratio",
                     groupvars=c("cln_name","actp.status","actp.mutation"))
wilcox.test(media_ratio ~ actp.status, data=d2_summ)
# W = 50, p-value = 0.347


# Difference of malthusian parameters -------------------------------------
bartlett.test(x = d2$media_difference, g = g) # 0.01985
fligner.test(x = d2$media_difference, g = g)  # 0.1552
leveneTest(d2$media_difference ~ d2$actp.status) # 0.097

mod00 <- lm(data=d2, media_difference ~ actp.status)
qqPlot(residuals(mod00))
shapiro.test(residuals(mod00)) # 0.0003514

# Data is (again) homoscedastic according to 2 out of 3 measures
# Boxcox transformation requires positive values
# as all values are negative, analyse their absolute value
boxcox(0-media_difference ~ actp.status, data=d2, lambda=seq(-5,5,0.5))
lbd <- 2

d2$media_difference.boxcox <- (((d2$media_difference)^lbd)-1)/lbd
bartlett.test(x = d2$media_difference.boxcox, g = g) # 0.011
fligner.test(x = d2$media_difference.boxcox, g = g)  # 0.07624
leveneTest(d2$media_difference.boxcox ~ d2$actp.status) # 0.05729

dmod01 <- lm(data=d2, media_difference.boxcox ~ actp.status)
qqPlot(residuals(dmod01))
shapiro.test(residuals(dmod01)) # 0.001903
stat.desc(residuals(dmod01), norm=TRUE)
plot(dmod01)
# Analysis of differences violates more model assumptions
# Heteroscedastic by one measure, and non-normal distribution of residuals
# Proceed with analysis but interpret with caution

anova(dmod01)
# Response: media_difference.boxcox
#             Df  Sum Sq   Mean Sq F value Pr(>F)
# actp.status  1 0.00715 0.0071544  0.5534 0.4595
# Residuals   67 0.86613 0.0129273
# Suggests no effect of actp status

# Create mixed effects dmodel to test

dmod0 <- gls(media_difference.boxcox ~ actp.status,
            method="REML", data=d2)
dmod1 <- lme(media_difference.boxcox ~ actp.status,
            random= ~1|cln_name,
            data=d2, method="REML")
anova(dmod0,dmod1)
# Correct for testing on boundary
loglik <- 2*(c(logLik(dmod1)-logLik(dmod0)))
0.5 * (1 - pchisq(loglik, 1))
# random effect of clone is significant p = 9.198198e-13

ranef(dmod1)

dmod1_ml <- update(dmod1, .~., method="ML")
drop1(dmod1_ml, test="Chisq")
#             Df     AIC     LRT Pr(>Chi)
# <none>         -145.97                 
# actp.status  1 -147.75 0.22186   0.6376

plot(dmod1)
d2$resid_d <- resid(dmod1, type="normalized")
ggplot(data=d2, aes(x=actp.status, y=resid_d, group=cln_name)) + 
  geom_point(position=position_dodge(width=0.2))
par(mfrow=c(1,1))
qqPlot(d2$resid_d)
# one extreme outlier
d2[52,] # C.03 (missense variant)

# Try also Wilcoxon test on the means as a nonparametric alternative
d2d_summ <- summarySE(d2, measurevar="media_difference",
                      groupvars=c("cln_name","actp.status","actp.mutation"))
wilcox.test(media_difference ~ actp.status, data=d2d_summ)
# W = 54, p-value = 0.4865

# Conclusion:
# We can detect no effect of actP mutation on differential growth in acetate.
# Measuring ratios of Malthusian parameters:
#     LRT Chisq(1) = 0.75931, p = 0.3835.
# Measuring differences of Mathusian parameters:
#     LRT Chisq(1) = 0.22186, p = 0.6376.
