##### Analysis of tellurite resistance in selected soil-evolved clones (disc diffusion) #####
# J. P. J. Hall, August 2018

rm(list=ls())

dat <- read.csv(file="./data/SuppTab8.csv",
         header=TRUE, sep=",")

dat$actp_status <- factor(dat$actp_status)

# Areas are all large and likely only slightly different from one another (if at all)
# Exploratory studies suggest that this can lead to rounding problems when transforming data
# Scale by dividing all areas by 2000

dat$area_scaled <- dat$area/2000

boxplot(dat$area_scaled ~ dat$actp_status) # maybe ok?
bartlett.test(x = dat$area_scaled, g = dat$actp_status) # p = 0.02617
fligner.test(x = dat$area_scaled, g = dat$actp_status) #  p = 0.1759
library(car)
leveneTest(dat$area_scaled ~ dat$actp_status) # 0.09803
# So Bartlett only one slightly out

mod00 <- lm(data=dat, area_scaled~actp_status)
qqPlot(resid(mod00))
shapiro.test(resid(mod00)) # 0.04703, indicates non-normal distribution of residuals

library(MASS)
boxcox(area_scaled ~ actp_status, data=dat, lambda=seq(-10,5,1))
boxcox(area_scaled ~ actp_status, data=dat, lambda=seq(-10,1,0.5))
# estimate at -4
lbd <- -4

dat$area.boxcox <- (((dat$area_scaled)^lbd)-1)/lbd

bartlett.test(x = dat$area.boxcox, g = dat$actp_status) # p = 0.1594
fligner.test(x =  dat$area.boxcox, g = dat$actp_status) #  p = 0.152
leveneTest(dat$area.boxcox ~ dat$actp_status) # 0.1899

mod01 <- lm(data=dat, area.boxcox~actp_status)
qqPlot(resid(mod01))
shapiro.test(resid(mod01)) # 0.5857
# Good

# Measure contribution of clone-clone variation
library(nlme)
mod0 <- gls(area.boxcox ~ actp_status,
    method="REML", data=dat)
mod1 <- lme(area.boxcox ~ actp_status, 
            random= ~1|cln_name,
            data=dat, method="REML")
anova(mod0,mod1) # 0.0333
# Testing on the boundary, so correct for this:
loglik <- 2*(c(logLik(mod1)-logLik(mod0)))
0.5 * (1 - pchisq(loglik, 1))
# random effect of clone is helpful (p = 0.01662802)

plot(mod1)

summary(mod1)

mod1_ml <- update(mod1, .~., method="ML")
drop1(mod1_ml, test="Chisq")
# Single term deletions
# area.boxcox ~ actp_status
#             Df     AIC     LRT Pr(>Chi)
# <none>         -284.83                 
# actp_status  1 -286.45 0.37412   0.5408
# No significant effect of actP status

dat$resid <- resid(mod1, type="normalized")
ggplot(data=dat, aes(x=actp_status, y=resid)) + geom_boxplot()


# Test alternative model: is there an effect of clone?

boxplot(dat$area_scaled ~ dat$cln_name)
bartlett.test(x = dat$area_scaled, g = dat$cln_name) # p = 0.7914
fligner.test(x = dat$area_scaled, g = dat$cln_name) #  p = 0.986

leveneTest(dat$area_scaled ~ dat$cln_name) # 0.9831

mod02 <- lm(data=dat, area_scaled~cln_name)
qqPlot(resid(mod02))
shapiro.test(resid(mod02)) # 0.257

anova(mod02)
#           Df   Sum Sq   Mean Sq F value    Pr(>F)    
# cln_name  20 0.130860 0.0065430  3.2005 0.0007376 ***
# Residuals 42 0.085862 0.0020443

t(t(coef(mod02)))
# (Intercept)            1.1783863333
# cln_nameA.02.65.G.011 -0.0257621667
# cln_nameA.03.65.S.004 -0.0294681667
# cln_nameA.04.65.S.011 -0.0469373333
# cln_nameA.10.65.G.006  0.0576220000
# cln_nameA.11.65.S.051 -0.0354771667
# cln_nameA.12.65.S.037  0.0153971667
# cln_nameB.02.65.G.021 -0.0383348333
# cln_nameB.03.65.S.005  0.0188330000
# cln_nameB.04.65.S.016  0.0492305000
# cln_nameB.09.65.G.029 -0.0062945000
# cln_nameB.10.65.G.004 -0.0109288333
# cln_nameB.11.65.S.044 -0.0393218333
# cln_nameB.12.65.S.042 -0.0383413333
# cln_nameC.01.65.G.021  0.1626473333  # This clone appears significantly more sensitive
# cln_nameC.02.65.G.016  0.0004046667
# cln_nameC.03.65.S.022  0.0321918333
# cln_nameC.04.65.S.004  0.0069608333
# cln_nameC.09.65.G.032 -0.0026391667
# cln_nameC.10.65.G.027 -0.0139438333
# cln_nameC.11.65.S.060  0.0108011667

# So in conclusion: disc diffusion assay shows no significant differences between
#   actP presence/absence and zone of clearing.
# However we can detect differences between clones, largely driven by one replicate (C01).
# This replicate is an actP mutant, so our prediction was that it would be more resistant,
#   however it is in fact more sensitive.
